@@ -210,7 +210,8 @@ TEST_CASE("Select all Physical Devices", "[VkBootstrap.bootstrap]") {
     VulkanMock& mock = get_and_setup_default();
     mock.api_version = VK_API_VERSION_1_1;
     mock.physical_devices_details[0].properties.apiVersion = VK_API_VERSION_1_1;
-    std::copy_n("mocking_gpus_for_fun_and_profit", VK_MAX_DRIVER_NAME_SIZE, mock.physical_devices_details[0].properties.deviceName);
+    const char* message = "mocking_gpus_for_fun_and_profit";
+    std::copy_n(message, sizeof(message) + 1, mock.physical_devices_details[0].properties.deviceName);
 
     auto instance = get_instance(1);
     auto surface = mock.get_new_surface(get_basic_surface_details());
@@ -709,7 +710,7 @@ TEST_CASE("Adding Optional Extension Features", "[VkBootstrap.enable_features_if
                 REQUIRE(!phys_dev.enable_extension_features_if_present(phys_dev_vulkan_11_features));
                 auto device = vkb::DeviceBuilder(phys_dev).build().value();
                 auto* s = reinterpret_cast<VkPhysicalDeviceVulkan12Features*>(
-                    &mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0));
+                    mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0).data());
                 REQUIRE(s->sType == VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_VULKAN_1_2_FEATURES);
                 vkb::destroy_device(device);
             }
@@ -721,7 +722,7 @@ TEST_CASE("Adding Optional Extension Features", "[VkBootstrap.enable_features_if
                 REQUIRE(phys_dev.enable_extension_features_if_present(phys_dev_vulkan_11_features));
                 auto device = vkb::DeviceBuilder(phys_dev).build().value();
                 auto* s = reinterpret_cast<VkPhysicalDeviceVulkan11Features*>(
-                    &mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(1));
+                    mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(1).data());
                 REQUIRE(s->sType == VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_VULKAN_1_1_FEATURES);
                 REQUIRE(s->shaderDrawParameters);
                 vkb::destroy_device(device);
@@ -883,10 +884,10 @@ TEST_CASE("Querying Vulkan 1.1 and 1.2 features", "[VkBootstrap.version]") {
             auto device_ret = device_builder.build();
             REQUIRE(device_ret.has_value());
             auto* s1 = reinterpret_cast<VkPhysicalDeviceVulkan11Features*>(
-                &mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0));
+                mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0).data());
             REQUIRE(s1->multiview);
             auto* s2 = reinterpret_cast<VkPhysicalDeviceVulkan12Features*>(
-                &mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(1));
+                mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(1).data());
             REQUIRE(s2->bufferDeviceAddress);
 
             vkb::destroy_device(device_ret.value());
@@ -968,7 +969,7 @@ TEST_CASE("Add required extension features in multiple calls", "[VkBootstrap.req
             auto device_ret = device_builder.build();
             REQUIRE(device_ret.has_value());
             auto* s1 = reinterpret_cast<VkPhysicalDeviceVulkan11Features*>(
-                &mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0));
+                mock.physical_devices_details.at(0).created_device_details.at(0).features_pNextChain.at(0).data());
             REQUIRE(s1->multiview);
             REQUIRE(s1->samplerYcbcrConversion);
 
@@ -977,3 +978,53 @@ TEST_CASE("Add required extension features in multiple calls", "[VkBootstrap.req
         vkb::destroy_instance(instance);
     }
 }
+
+// Simple Rule of 3 type
+class Sample {
+    public:
+    Sample() { data = new int; }
+    Sample(Sample const& sample) {
+        data = new int;
+        *data = *sample.data;
+    }
+    Sample& operator=(Sample const& sample) {
+
+        *data = *sample.data;
+        return *this;
+    }
+
+    virtual ~Sample() { delete data; }
+
+    private:
+    int* data;
+};
+
+TEST_CASE("Check vkb::Result", "[VkBootstrap.Result]") {
+    {
+        vkb::Result<std::vector<float>> a{ std::vector<float>(30, 3.0f) };
+        auto b = std::move(a);
+        b.value().push_back(5.0f);
+        vkb::Result<std::vector<float>> c{ std::move(b) };
+        c.value().push_back(7.0f);
+        auto d = std::move(c);
+        d.value().push_back(9.0f);
+    }
+    {
+        vkb::Result<std::unique_ptr<float>> a{ std::make_unique<float>(3.0f) };
+        vkb::Result<std::unique_ptr<float>> b{ std::make_unique<float>(3.0f) };
+        b = std::move(a);
+        *b.value().get() = 5.0f;
+        vkb::Result<std::unique_ptr<float>> c{ std::move(b) };
+        *c.value().get() = 7.0f;
+        auto d = std::move(c);
+        *d.value().get() = 9.0f;
+    }
+    {
+
+        vkb::Result<Sample> result(Sample{});
+        vkb::Result<Sample> anotherResult(std::move(result));
+        vkb::Result<Sample> c = result;
+        vkb::Result<Sample> d(Sample{});
+        d = c;
+    }
+}
